@@ -1,7 +1,7 @@
 #' High-Dimensional Regularized Discriminant Analysis (HDRDA)
 #'
 #' Given a set of training data, this function builds the HDRDA classifier from
-#' Ramey, Stein, and Young (2014). Specially designed for small-sample,
+#' Ramey, Stein, and Young (2017). Specially designed for small-sample,
 #' high-dimensional data, the HDRDA classifier incorporates dimension reduction
 #' and covariance-matrix shrinkage to enable a computationally efficient
 #' classifier.
@@ -18,7 +18,7 @@
 #' \deqn{\tilde{\Sigma}_k = \alpha_k \hat{\Sigma}_k(\lambda) + \gamma I_p,}
 #' where \eqn{I_p} is the \eqn{p \times p} identity matrix. The matrix
 #' \eqn{\tilde{\Sigma}_k} is substituted into the HDRDA classifier. See Ramey et
-#' al. (2014) for more details.
+#' al. (2017) for more details.
 #'
 #' The matrix of training observations are given in \code{x}. The rows of
 #' \code{x} contain the sample observations, and the columns contain the features
@@ -31,12 +31,13 @@
 #' probabilities are estimated as the sample proportion of observations
 #' belonging to each class. Otherwise, \code{prior} should be a vector with the
 #' same length as the number of classes in \code{y}. The \code{prior}
-#' probabilties should be nonnegative and sum to one. The order of the prior
-#' probabilties is assumed to match the levels of \code{factor(y)}.
+#' probabilities should be nonnegative and sum to one. The order of the prior
+#' probabilities is assumed to match the levels of \code{factor(y)}.
 #'
 #' @export
-#' @references Ramey, J. A., Stein, C. K., and Young, D. M. (2014),
+#' @references Ramey, J. A., Stein, C. K., and Young, D. M. (2017),
 #' "High-Dimensional Regularized Discriminant Analysis."
+#' \url{https://arxiv.org/abs/1602.01182}.
 #' @references Friedman, J. H. (1989), "Regularized Discriminant Analysis,"
 #' Journal of American Statistical Association, 84, 405, 165-175.
 #' \url{http://www.jstor.org/pss/2289860} (Requires full-text access).
@@ -48,7 +49,7 @@
 #' @param gamma a numeric values used for the shrinkage parameter.
 #' @param shrinkage_type the type of covariance-matrix shrinkage to apply. By
 #' default, a ridge-like shrinkage is applied. If \code{convex} is given, then
-#' shrinkage similar to Friedman (1989) is applied. See Ramey et al. (2014) for
+#' shrinkage similar to Friedman (1989) is applied. See Ramey et al. (2017) for
 #' details.
 #' @param prior vector with prior probabilities for each class. If \code{NULL}
 #' (default), then the sample proportion of observations belonging to each class
@@ -209,7 +210,7 @@ print.hdrda <- function(x, ...) {
   print(x$p)
   cat("Classes:\n")
   print(x$groups)
-  cat("Prior Probabilties:\n")
+  cat("Prior Probabilities:\n")
   print(sapply(x$est, function(z) z$prior))
   cat("Reduced dimension, q:\n")
   print(x$q)
@@ -311,7 +312,7 @@ predict.hdrda <- function(object, newdata, projected = FALSE, ...) {
 #' @param num_gamma The number of values of \code{gamma} to consider
 #' @param shrinkage_type the type of covariance-matrix shrinkage to apply. By
 #' default, a ridge-like shrinkage is applied. If \code{convex} is given, then
-#' shrinkage similar to Friedman (1989) is applied. See Ramey et al. (2014) for
+#' shrinkage similar to Friedman (1989) is applied. See Ramey et al. (2017) for
 #' details.
 #' @param verbose If set to \code{TRUE}, summary information will be outputted
 #' as the optimal model is being determined.
