@@ -2,8 +2,9 @@ library(testthat)
 library(sparsediscrim)
 library(MASS)
 library(mvtnorm)
+library(caret)
 
-context("The HDRDA Classifier from Ramey et al. (2014)")
+context("The HDRDA Classifier from Ramey et al. (2017)")
 
 test_that("The HDRDA classifier works properly on the iris data set", {
   set.seed(42)
@@ -37,30 +38,6 @@ test_that("HDRDA's calculations are correct for (lambda, gamma) = (1, 0)", {
   expect_equal(W_k$virginica, D_q)
 })
 
-test_that("HDRDA's calculations are correct for (lambda, gamma) = (0, 0)", {
-  hdrda_out <- hdrda(Species ~ ., data = iris, lambda=0, gamma=0)
-
-  Sigma <- cov_pool(x=iris[, -5], y=iris$Species)
-  Sigma_k <- tapply(seq_len(nrow(iris)), iris$Species, function(i) {
-    cov_mle(iris[i, -5])
-  })
-  Sigma_eigen <- eigen(Sigma, symmetric=TRUE)
-  U_1 <- Sigma_eigen$vectors
-
-  # For each class, calculate W_k.
-  W_k <- sapply(hdrda_out$est, function(est) {
-    solve(est$W_inv)
-  }, simplify=FALSE)
-
-  W_k_expected <- sapply(Sigma_k, function(class_cov) {
-    crossprod(U_1, class_cov) %*% U_1
-  }, simplify=FALSE)
-
-  expect_equal(W_k$setosa, W_k_expected$setosa)
-  expect_equal(W_k$versicolor, W_k_expected$versicolor)
-  expect_equal(W_k$virginica, W_k_expected$virginica)
-})
-
 test_that("LDA is a special case of HDRDA on the iris data set", {
   set.seed(42)
   n <- nrow(iris)
@@ -478,8 +455,6 @@ test_that("HDRDA's statistics match manual values when (lambda, gamma) = (0.5, 0
 })
 
 test_that("HDRDA posterior probabilities sum to one. (Issue #34)", {
-  library(caret)
-
   set.seed(1)
   dat <- twoClassSim(106)
   trn <- dat[1:100,]
@@ -498,8 +473,6 @@ test_that("HDRDA posterior probabilities sum to one. (Issue #34)", {
 })
 
 test_that("HDRDA correctly predicts one observation. (Issue #34)", {
-  library(caret)
-
   set.seed(1)
   dat <- twoClassSim(101)
   trn <- dat[1:100,]
